ConversionProperties

Struct ConversionProperties 

pub struct ConversionProperties {
    pub coefficients: Option<[f32; 9]>,
    pub preoffsets: Option<[f32; 3]>,
    pub postoffsets: Option<[f32; 3]>,
    /* private fields */
}
The properties required to apply color conversion to the display. The conversion is applied to each pixel of the display according to the formula:

[coefficients * (pixel + preoffsets) + postoffsets].

where pixel is a column vector consisting of the pixel’s 3 RGB components.

Fields

coefficients: Option<[f32; 9]>

The |coefficients| param represents a 3x3 matrix, where the values are given in row-major order:

| 0 1 2 | | 3 4 5 | | 6 7 8 |

preoffsets: Option<[f32; 3]>

Preoffsets and postoffsets represent a [3x1] vector each of RGB values.

postoffsets: Option<[f32; 3]>